@@ -72,9 +72,9 @@ use namespace::autoclean;
 use utf8;
 
 # ABSTRACT: Test your Dist::Zilla plugin
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
-use Dist::Zilla::Tester::DieHard;
+use Dist::Zilla::Tester::DieHard 0.002;     # DieHard v0.001 rethrows modified exception.
 use File::Temp qw{ tempdir };
 use Test::DZil qw{ dist_ini };
 use Test::More;
@@ -533,7 +533,7 @@ Test::Dist::Zilla - Test your Dist::Zilla plugin
 
 =head1 VERSION
 
-Version 0.001, released on 2015-08-23 23:03 UTC.
+Version 0.002, released on 2015-08-29 19:03 UTC.
 
 =head1 SYNOPSIS
 
